hintAfter constant

Duration const hintAfter

How long to wait before assuming the app is never going to write the file, and explaining why that usually happens.

Implementation

static const Duration hintAfter = Duration(seconds: 12);